@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- *  Copyright (C) 2000-2007 Jeffrey Stedfast
+ *  Copyright (C) 2000-2008 Jeffrey Stedfast
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -80,7 +80,6 @@ static void
 write_part_bodystructure (GMimeObject *part, FILE *fp)
 {
 	GMimeParam *param;
-	GList *l;
 	
 	fputc ('(', fp);
 	
@@ -104,10 +103,15 @@ write_part_bodystructure (GMimeObject *part, FILE *fp)
 	}
 	
 	if (GMIME_IS_MULTIPART (part)) {
-		l = GMIME_MULTIPART (part)->subparts;
-		while (l != NULL) {
-			write_part_bodystructure (l->data, fp);
-			l = l->next;
+		GMimeMultipart *multipart = (GMimeMultipart *) part;
+		GMimeObject *subpart;
+		int i, n;
+		
+		n = g_mime_multipart_get_number (multipart);
+		for (i = 0; i < n; i++) {
+			subpart = g_mime_multipart_get_part (multipart, i);
+			write_part_bodystructure (subpart, fp);
+			g_object_unref (subpart);
 		}
 	} else if (GMIME_IS_MESSAGE_PART (part)) {
 		GMimeMessage *message;
@@ -119,60 +123,60 @@ write_part_bodystructure (GMimeObject *part, FILE *fp)
 		/* print envelope */
 		fputc ('(', fp);
 		
-		nstring = g_mime_message_get_date_string (message);
+		nstring = g_mime_message_get_date_as_string (message);
 		fprintf (fp, "\"%s\" ", nstring);
 		g_free (nstring);
 		
-		if ((str = g_mime_message_get_header (message, "Subject")))
+		if ((str = g_mime_object_get_header ((GMimeObject *) message, "Subject")))
 			nstring = escape_string (str);
 		else
 			nstring = g_strdup ("");
 		fprintf (fp, "\"%s\" ", nstring);
 		g_free (nstring);
 		
-		if ((str = g_mime_message_get_header (message, "From")))
+		if ((str = g_mime_object_get_header ((GMimeObject *) message, "From")))
 			nstring = escape_string (str);
 		else
 			nstring = g_strdup ("");
 		fprintf (fp, "\"%s\" ", nstring);
 		g_free (nstring);
 		
-		if ((str = g_mime_message_get_header (message, "Sender")))
+		if ((str = g_mime_object_get_header ((GMimeObject *) message, "Sender")))
 			nstring = escape_string (str);
 		else
 			nstring = g_strdup ("");
 		fprintf (fp, "\"%s\" ", nstring);
 		g_free (nstring);
 		
-		if ((str = g_mime_message_get_header (message, "Reply-To")))
+		if ((str = g_mime_object_get_header ((GMimeObject *) message, "Reply-To")))
 			nstring = escape_string (str);
 		else
 			nstring = g_strdup ("");
 		fprintf (fp, "\"%s\" ", nstring);
 		g_free (nstring);
 		
-		if ((str = g_mime_message_get_header (message, "To")))
+		if ((str = g_mime_object_get_header ((GMimeObject *) message, "To")))
 			nstring = escape_string (str);
 		else
 			nstring = g_strdup ("");
 		fprintf (fp, "\"%s\" ", nstring);
 		g_free (nstring);
 		
-		if ((str = g_mime_message_get_header (message, "Cc")))
+		if ((str = g_mime_object_get_header ((GMimeObject *) message, "Cc")))
 			nstring = escape_string (str);
 		else
 			nstring = g_strdup ("");
 		fprintf (fp, "\"%s\" ", nstring);
 		g_free (nstring);
 		
-		if ((str = g_mime_message_get_header (message, "Bcc")))
+		if ((str = g_mime_object_get_header ((GMimeObject *) message, "Bcc")))
 			nstring = escape_string (str);
 		else
 			nstring = g_strdup ("");
 		fprintf (fp, "\"%s\" ", nstring);
 		g_free (nstring);
 		
-		if ((str = g_mime_message_get_header (message, "In-Reply-To")))
+		if ((str = g_mime_object_get_header ((GMimeObject *) message, "In-Reply-To")))
 			nstring = escape_string (str);
 		else
 			nstring = g_strdup ("");
@@ -191,9 +195,9 @@ write_part_bodystructure (GMimeObject *part, FILE *fp)
 		/* print body */
 		write_part_bodystructure ((GMimeObject *) message->mime_part, fp);
 	} else if (GMIME_IS_PART (part)) {
-		if (GMIME_PART (part)->disposition) {
-			fprintf (fp, "\"%s\" ", GMIME_PART (part)->disposition->disposition);
-			if ((param = GMIME_PART (part)->disposition->params)) {
+		if (GMIME_OBJECT (part)->disposition) {
+			fprintf (fp, "\"%s\" ", GMIME_OBJECT (part)->disposition->disposition);
+			if ((param = GMIME_OBJECT (part)->disposition->params)) {
 				fputc ('(', fp);
 				while (param) {
 					fprintf (fp, "\"%s\" \"%s\"", param->name, param->value);
@@ -209,22 +213,22 @@ write_part_bodystructure (GMimeObject *part, FILE *fp)
 		}
 		
 		switch (GMIME_PART (part)->encoding) {
-		case GMIME_PART_ENCODING_7BIT:
+		case GMIME_CONTENT_ENCODING_7BIT:
 			fputs ("\"7bit\"", fp);
 			break;
-		case GMIME_PART_ENCODING_8BIT:
+		case GMIME_CONTENT_ENCODING_8BIT:
 			fputs ("\"8bit\"", fp);
 			break;
-		case GMIME_PART_ENCODING_BINARY:
+		case GMIME_CONTENT_ENCODING_BINARY:
 			fputs ("\"binary\"", fp);
 			break;
-		case GMIME_PART_ENCODING_BASE64:
+		case GMIME_CONTENT_ENCODING_BASE64:
 			fputs ("\"base64\"", fp);
 			break;
-		case GMIME_PART_ENCODING_QUOTEDPRINTABLE:
+		case GMIME_CONTENT_ENCODING_QUOTEDPRINTABLE:
 			fputs ("\"quoted-printable\"", fp);
 			break;
-		case GMIME_PART_ENCODING_UUENCODE:
+		case GMIME_CONTENT_ENCODING_UUENCODE:
 			fputs ("\"x-uuencode\"", fp);
 			break;
 		default:
@@ -272,10 +276,12 @@ static void
 write_part (GMimeObject *part, const char *uid, const char *spec)
 {
 	GMimeStream *istream, *ostream;
+	GMimeMultipart *multipart;
+	GMimeMessage *message;
+	GMimeObject *subpart;
 	char *buf, *id;
-	GList *l;
 	FILE *fp;
-	int i;
+	int i, n;
 	
 	buf = g_strdup_printf ("%s/%s.HEADER", uid, spec);
 	fp = fopen (buf, "wt");
@@ -288,20 +294,19 @@ write_part (GMimeObject *part, const char *uid, const char *spec)
 	fclose (fp);
 	
 	if (GMIME_IS_MULTIPART (part)) {
+		multipart = (GMimeMultipart *) part;
 		buf = g_alloca (strlen (spec) + 14);
 		id = g_stpcpy (buf, spec);
 		*id++ = '.';
-		i = 1;
-		l = GMIME_MULTIPART (part)->subparts;
-		while (l != NULL) {
-			sprintf (id, "%d", i);
-			write_part (l->data, uid, buf);
-			l = l->next;
-			i++;
+		
+		n = g_mime_multipart_get_number (multipart);
+		for (i = 0; i < n; i++) {
+			subpart = g_mime_multipart_get_part (multipart, i);
+			sprintf (id, "%d", i + 1);
+			write_part (subpart, uid, buf);
+			g_object_unref (subpart);
 		}
 	} else if (GMIME_IS_MESSAGE_PART (part)) {
-		GMimeMessage *message;
-		
 		buf = g_strdup_printf ("%s/%s.TEXT", uid, spec);
 		fp = fopen (buf, "wt");
 		g_free (buf);
@@ -310,7 +315,7 @@ write_part (GMimeObject *part, const char *uid, const char *spec)
 		
 		ostream = g_mime_stream_file_new (fp);
 		g_mime_object_write_to_stream (GMIME_OBJECT (message), ostream);
-		g_mime_stream_unref (ostream);
+		g_object_unref (ostream);
 	} else if (GMIME_IS_PART (part)) {
 		buf = g_strdup_printf ("%s/%s.TEXT", uid, spec);
 		fp = fopen (buf, "wt");
@@ -320,8 +325,8 @@ write_part (GMimeObject *part, const char *uid, const char *spec)
 		istream = g_mime_data_wrapper_get_stream (GMIME_PART (part)->content);
 		
 		g_mime_stream_write_to_stream (istream, ostream);
-		g_mime_stream_unref (istream);
-		g_mime_stream_unref (ostream);
+		g_object_unref (istream);
+		g_object_unref (ostream);
 	}
 }
 
