@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*  GMime
- *  Copyright (C) 2000-2009 Jeffrey Stedfast
+ *  Copyright (C) 2000-2008 Jeffrey Stedfast
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Lesser General Public License
@@ -59,8 +59,8 @@ static int cipher_encrypt (GMimeCipherContext *ctx, gboolean sign,
 			   GMimeStream *istream, GMimeStream *ostream,
 			   GError **err);
 
-static int cipher_decrypt (GMimeCipherContext *ctx, GMimeStream *istream,
-			   GMimeStream *ostream, GError **err);
+static GMimeSignatureValidity *cipher_decrypt (GMimeCipherContext *ctx, GMimeStream *istream,
+					       GMimeStream *ostream, GError **err);
 
 static int cipher_import_keys (GMimeCipherContext *ctx, GMimeStream *istream,
 			       GError **err);
@@ -142,16 +142,16 @@ cipher_hash_id (GMimeCipherContext *ctx, const char *hash)
 
 
 /**
- * g_mime_cipher_hash_id:
+ * g_mime_cipher_context_hash_id:
  * @ctx: Cipher Context
  * @hash: hash name
  *
  * Gets the hash id based on the hash name @hash.
  *
- * Returns the equivalent hash id or #GMIME_CIPHER_HASH_DEFAULT on fail.
+ * Returns: the equivalent hash id or #GMIME_CIPHER_HASH_DEFAULT on fail.
  **/
 GMimeCipherHash
-g_mime_cipher_hash_id (GMimeCipherContext *ctx, const char *hash)
+g_mime_cipher_context_hash_id (GMimeCipherContext *ctx, const char *hash)
 {
 	g_return_val_if_fail (GMIME_IS_CIPHER_CONTEXT (ctx), GMIME_CIPHER_HASH_DEFAULT);
 	g_return_val_if_fail (hash != NULL, GMIME_CIPHER_HASH_DEFAULT);
@@ -168,16 +168,16 @@ cipher_hash_name (GMimeCipherContext *ctx, GMimeCipherHash hash)
 
 
 /**
- * g_mime_cipher_hash_name:
+ * g_mime_cipher_context_hash_name:
  * @ctx: Cipher Context
  * @hash: hash id
  *
  * Gets the hash name based on the hash id @hash.
  *
- * Returns the equivalent hash name or %NULL on fail.
+ * Returns: the equivalent hash name or %NULL on fail.
  **/
 const char *
-g_mime_cipher_hash_name (GMimeCipherContext *ctx, GMimeCipherHash hash)
+g_mime_cipher_context_hash_name (GMimeCipherContext *ctx, GMimeCipherHash hash)
 {
 	g_return_val_if_fail (GMIME_IS_CIPHER_CONTEXT (ctx), NULL);
 	
@@ -197,7 +197,7 @@ cipher_sign (GMimeCipherContext *ctx, const char *userid, GMimeCipherHash hash,
 
 
 /**
- * g_mime_cipher_sign:
+ * g_mime_cipher_context_sign:
  * @ctx: Cipher Context
  * @userid: private key to use to sign the stream
  * @hash: preferred Message-Integrity-Check hash algorithm
@@ -207,11 +207,12 @@ cipher_sign (GMimeCipherContext *ctx, const char *userid, GMimeCipherHash hash,
  *
  * Signs the input stream and writes the resulting signature to the output stream.
  *
- * Returns %0 on success or %-1 on fail.
+ * Returns: the #GMimeCipherHash used on success (useful if @hash is
+ * specified as #GMIME_CIPHER_HASH_DEFAULT) or %-1 on fail.
  **/
 int
-g_mime_cipher_sign (GMimeCipherContext *ctx, const char *userid, GMimeCipherHash hash,
-		    GMimeStream *istream, GMimeStream *ostream, GError **err)
+g_mime_cipher_context_sign (GMimeCipherContext *ctx, const char *userid, GMimeCipherHash hash,
+			    GMimeStream *istream, GMimeStream *ostream, GError **err)
 {
 	g_return_val_if_fail (GMIME_IS_CIPHER_CONTEXT (ctx), -1);
 	g_return_val_if_fail (GMIME_IS_STREAM (istream), -1);
@@ -233,7 +234,7 @@ cipher_verify (GMimeCipherContext *ctx, GMimeCipherHash hash, GMimeStream *istre
 
 
 /**
- * g_mime_cipher_verify:
+ * g_mime_cipher_context_verify:
  * @ctx: Cipher Context
  * @hash: secure hash used
  * @istream: input stream
@@ -245,13 +246,13 @@ cipher_verify (GMimeCipherContext *ctx, GMimeCipherHash hash, GMimeStream *istre
  * @sigstream is assumed to be the signature stream and is used to
  * verify the integirity of the @istream.
  *
- * Returns a #GMimeSignatureValidity structure containing information
+ * Returns: a #GMimeSignatureValidity structure containing information
  * about the integrity of the input stream or %NULL on failure to
  * execute at all.
  **/
 GMimeSignatureValidity *
-g_mime_cipher_verify (GMimeCipherContext *ctx, GMimeCipherHash hash, GMimeStream *istream,
-		      GMimeStream *sigstream, GError **err)
+g_mime_cipher_context_verify (GMimeCipherContext *ctx, GMimeCipherHash hash, GMimeStream *istream,
+			      GMimeStream *sigstream, GError **err)
 {
 	g_return_val_if_fail (GMIME_IS_CIPHER_CONTEXT (ctx), NULL);
 	g_return_val_if_fail (GMIME_IS_STREAM (istream), NULL);
@@ -272,7 +273,7 @@ cipher_encrypt (GMimeCipherContext *ctx, gboolean sign, const char *userid, GPtr
 
 
 /**
- * g_mime_cipher_encrypt:
+ * g_mime_cipher_context_encrypt:
  * @ctx: Cipher Context
  * @sign: sign as well as encrypt
  * @userid: key id (or email address) to use when signing (assuming @sign is %TRUE)
@@ -284,11 +285,11 @@ cipher_encrypt (GMimeCipherContext *ctx, gboolean sign, const char *userid, GPtr
  * Encrypts (and optionally signs) the cleartext input stream and
  * writes the resulting ciphertext to the output stream.
  *
- * Returns %0 on success or %-1 on fail.
+ * Returns: %0 on success or %-1 on fail.
  **/
 int
-g_mime_cipher_encrypt (GMimeCipherContext *ctx, gboolean sign, const char *userid, GPtrArray *recipients,
-		       GMimeStream *istream, GMimeStream *ostream, GError **err)
+g_mime_cipher_context_encrypt (GMimeCipherContext *ctx, gboolean sign, const char *userid, GPtrArray *recipients,
+			       GMimeStream *istream, GMimeStream *ostream, GError **err)
 {
 	g_return_val_if_fail (GMIME_IS_CIPHER_CONTEXT (ctx), -1);
 	g_return_val_if_fail (GMIME_IS_STREAM (istream), -1);
@@ -298,19 +299,19 @@ g_mime_cipher_encrypt (GMimeCipherContext *ctx, gboolean sign, const char *useri
 }
 
 
-static int
+static GMimeSignatureValidity *
 cipher_decrypt (GMimeCipherContext *ctx, GMimeStream *istream,
 		GMimeStream *ostream, GError **err)
 {
 	g_set_error (err, GMIME_ERROR_QUARK, GMIME_ERROR_NOT_SUPPORTED,
 		     "Decryption is not supported by this cipher");
 	
-	return -1;
+	return NULL;
 }
 
 
 /**
- * g_mime_cipher_decrypt:
+ * g_mime_cipher_context_decrypt:
  * @ctx: Cipher Context
  * @istream: input/ciphertext stream
  * @ostream: output/cleartext stream
@@ -319,15 +320,24 @@ cipher_decrypt (GMimeCipherContext *ctx, GMimeStream *istream,
  * Decrypts the ciphertext input stream and writes the resulting
  * cleartext to the output stream.
  *
- * Returns %0 on success or %-1 for fail.
+ * If the encrypted input stream was also signed, the returned
+ * #GMimeSignatureValidity will have signer information included and
+ * the signature status will be one of #GMIME_SIGNATURE_STATUS_GOOD,
+ * #GMIME_SIGNATURE_STATUS_BAD, or #GMIME_SIGNATURE_STATUS_UNKNOWN.
+ *
+ * If the encrypted input text was not signed, then the signature
+ * status of the returned #GMimeSignatureValidity will be
+ * #GMIME_SIGNATURE_STATUS_NONE.
+ *
+ * Returns: a #GMimeSignatureValidity on success or %NULL on error.
  **/
-int
-g_mime_cipher_decrypt (GMimeCipherContext *ctx, GMimeStream *istream,
-		       GMimeStream *ostream, GError **err)
+GMimeSignatureValidity *
+g_mime_cipher_context_decrypt (GMimeCipherContext *ctx, GMimeStream *istream,
+			       GMimeStream *ostream, GError **err)
 {
-	g_return_val_if_fail (GMIME_IS_CIPHER_CONTEXT (ctx), -1);
-	g_return_val_if_fail (GMIME_IS_STREAM (istream), -1);
-	g_return_val_if_fail (GMIME_IS_STREAM (ostream), -1);
+	g_return_val_if_fail (GMIME_IS_CIPHER_CONTEXT (ctx), NULL);
+	g_return_val_if_fail (GMIME_IS_STREAM (istream), NULL);
+	g_return_val_if_fail (GMIME_IS_STREAM (ostream), NULL);
 	
 	return GMIME_CIPHER_CONTEXT_GET_CLASS (ctx)->decrypt (ctx, istream, ostream, err);
 }
@@ -344,7 +354,7 @@ cipher_import_keys (GMimeCipherContext *ctx, GMimeStream *istream, GError **err)
 
 
 /**
- * g_mime_cipher_import_keys:
+ * g_mime_cipher_context_import_keys:
  * @ctx: Cipher Context
  * @istream: input stream (containing keys)
  * @err: exception
@@ -352,10 +362,10 @@ cipher_import_keys (GMimeCipherContext *ctx, GMimeStream *istream, GError **err)
  * Imports a stream of keys/certificates contained within @istream
  * into the key/certificate database controlled by @ctx.
  *
- * Returns %0 on success or %-1 on fail.
+ * Returns: %0 on success or %-1 on fail.
  **/
 int
-g_mime_cipher_import_keys (GMimeCipherContext *ctx, GMimeStream *istream, GError **err)
+g_mime_cipher_context_import_keys (GMimeCipherContext *ctx, GMimeStream *istream, GError **err)
 {
 	g_return_val_if_fail (GMIME_IS_CIPHER_CONTEXT (ctx), -1);
 	g_return_val_if_fail (GMIME_IS_STREAM (istream), -1);
@@ -376,7 +386,7 @@ cipher_export_keys (GMimeCipherContext *ctx, GPtrArray *keys,
 
 
 /**
- * g_mime_cipher_export_keys:
+ * g_mime_cipher_context_export_keys:
  * @ctx: Cipher Context
  * @keys: an array of key ids
  * @ostream: output stream
@@ -385,11 +395,11 @@ cipher_export_keys (GMimeCipherContext *ctx, GPtrArray *keys,
  * Exports the keys/certificates in @keys to the stream @ostream from
  * the key/certificate database controlled by @ctx.
  *
- * Returns %0 on success or %-1 on fail.
+ * Returns: %0 on success or %-1 on fail.
  **/
 int
-g_mime_cipher_export_keys (GMimeCipherContext *ctx, GPtrArray *keys,
-			   GMimeStream *ostream, GError **err)
+g_mime_cipher_context_export_keys (GMimeCipherContext *ctx, GPtrArray *keys,
+				   GMimeStream *ostream, GError **err)
 {
 	g_return_val_if_fail (GMIME_IS_CIPHER_CONTEXT (ctx), -1);
 	g_return_val_if_fail (GMIME_IS_STREAM (ostream), -1);
@@ -404,7 +414,7 @@ g_mime_cipher_export_keys (GMimeCipherContext *ctx, GPtrArray *keys,
  *
  * Allocates an new GMimeSigner.
  *
- * Returns a new #GMimeSigner.
+ * Returns: a new #GMimeSigner.
  **/
 GMimeSigner *
 g_mime_signer_new (void)
@@ -415,8 +425,8 @@ g_mime_signer_new (void)
 	signer->status = GMIME_SIGNER_STATUS_NONE;
 	signer->errors = GMIME_SIGNER_ERROR_NONE;
 	signer->trust = GMIME_SIGNER_TRUST_NONE;
-	signer->sig_created = (time_t) 0;
-	signer->sig_expire = (time_t) 0;
+	signer->created = (time_t) 0;
+	signer->expires = (time_t) 0;
 	signer->fingerprint = NULL;
 	signer->keyid = NULL;
 	signer->name = NULL;
@@ -442,12 +452,296 @@ g_mime_signer_free (GMimeSigner *signer)
 }
 
 
+/**
+ * g_mime_signer_next:
+ * @signer: a #GMimeSigner
+ *
+ * Advance to the next signer.
+ *
+ * Returns: the next #GMimeSigner or %NULL when complete.
+ **/
+GMimeSigner *
+g_mime_signer_next (GMimeSigner *signer)
+{
+	g_return_val_if_fail (signer != NULL, NULL);
+	
+	return signer->next;
+}
+
+
+/**
+ * g_mime_signer_set_status:
+ * @signer: a #GMimeSigner
+ * @status: a #GMimeSignerStatus
+ *
+ * Set the status on the signer.
+ **/
+void
+g_mime_signer_set_status (GMimeSigner *signer, GMimeSignerStatus status)
+{
+	g_return_if_fail (signer != NULL);
+	
+	signer->status = status;
+}
+
+
+/**
+ * g_mime_signer_get_status:
+ * @signer: a #GMimeSigner
+ *
+ * Get the signer status.
+ *
+ * Returns: the signer status.
+ **/
+GMimeSignerStatus
+g_mime_signer_get_status (GMimeSigner *signer)
+{
+	g_return_val_if_fail (signer != NULL, GMIME_SIGNER_STATUS_NONE);
+	
+	return signer->status;
+}
+
+
+/**
+ * g_mime_signer_set_errors:
+ * @signer: a #GMimeSigner
+ * @error: a #GMimeSignerError
+ *
+ * Set the errors on the signer.
+ **/
+void
+g_mime_signer_set_errors (GMimeSigner *signer, GMimeSignerError errors)
+{
+	g_return_if_fail (signer != NULL);
+	
+	signer->errors = errors;
+}
+
+
+/**
+ * g_mime_signer_get_errors:
+ * @signer: a #GMimeSigner
+ *
+ * Get the signer errors.
+ *
+ * Returns: the signer errors.
+ **/
+GMimeSignerError
+g_mime_signer_get_error (GMimeSigner *signer)
+{
+	g_return_val_if_fail (signer != NULL, GMIME_SIGNER_ERROR_NONE);
+	
+	return signer->errors;
+}
+
+
+/**
+ * g_mime_signer_set_trust:
+ * @signer: a #GMimeSigner
+ * @trust: a #GMimeSignerTrust
+ *
+ * Set the signer trust.
+ **/
+void
+g_mime_signer_set_trust (GMimeSigner *signer, GMimeSignerTrust trust)
+{
+	g_return_if_fail (signer != NULL);
+	
+	signer->trust = trust;
+}
+
+
+/**
+ * g_mime_signer_get_trust:
+ * @signer: a #GMimeSigner
+ *
+ * Get the signer trust.
+ *
+ * Returns: the signer trust.
+ **/
+GMimeSignerTrust
+g_mime_signer_get_trust (GMimeSigner *signer)
+{
+	g_return_val_if_fail (signer != NULL, GMIME_SIGNER_TRUST_NONE);
+	
+	return signer->trust;
+}
+
+
+/**
+ * g_mime_signer_set_fingerprint:
+ * @signer: a #GMimeSigner
+ * @fingerprint: fingerprint string
+ *
+ * Set the signer's key fingerprint.
+ **/
+void
+g_mime_signer_set_fingerprint (GMimeSigner *signer, const char *fingerprint)
+{
+	g_return_if_fail (signer != NULL);
+	
+	g_free (signer->fingerprint);
+	signer->fingerprint = g_strdup (fingerprint);
+}
+
+
+/**
+ * g_mime_signer_get_fingerprint:
+ * @signer: a #GMimeSigner
+ *
+ * Get the signer's key fingerprint.
+ *
+ * Returns: the signer's key fingerprint.
+ **/
+const char *
+g_mime_signer_get_fingerprint (GMimeSigner *signer)
+{
+	g_return_val_if_fail (signer != NULL, NULL);
+	
+	return signer->fingerprint;
+}
+
+
+/**
+ * g_mime_signer_set_key_id:
+ * @signer: a #GMimeSigner
+ * @key_id: key id
+ *
+ * Set the signer's key id.
+ **/
+void
+g_mime_signer_set_key_id (GMimeSigner *signer, const char *key_id)
+{
+	g_return_if_fail (signer != NULL);
+	
+	g_free (signer->keyid);
+	signer->keyid = g_strdup (key_id);
+}
+
+
+/**
+ * g_mime_signer_get_key_id:
+ * @signer: a #GMimeSigner
+ *
+ * Get the signer's key id.
+ *
+ * Returns: the signer's key id.
+ **/
+const char *
+g_mime_signer_get_key_id (GMimeSigner *signer)
+{
+	g_return_val_if_fail (signer != NULL, NULL);
+	
+	return signer->keyid;
+}
+
+
+/**
+ * g_mime_signer_set_name:
+ * @signer: a #GMimeSigner
+ * @name: signer's name
+ *
+ * Set the signer's name.
+ **/
+void
+g_mime_signer_set_name (GMimeSigner *signer, const char *name)
+{
+	g_return_if_fail (signer != NULL);
+	
+	g_free (signer->name);
+	signer->name = g_strdup (name);
+}
+
+
+/**
+ * g_mime_signer_get_name:
+ * @signer: a #GMimeSigner
+ *
+ * Get the signer trust.
+ *
+ * Returns: the signer trust.
+ **/
+const char *
+g_mime_signer_get_name (GMimeSigner *signer)
+{
+	g_return_val_if_fail (signer != NULL, NULL);
+	
+	return signer->name;
+}
+
+
+/**
+ * g_mime_signer_set_created:
+ * @signer: a #GMimeSigner
+ * @created: creation date
+ *
+ * Set the signer's key creation date.
+ **/
+void
+g_mime_signer_set_created (GMimeSigner *signer, time_t created)
+{
+	g_return_if_fail (signer != NULL);
+	
+	signer->created = created;
+}
+
+
+/**
+ * g_mime_signer_get_created:
+ * @signer: a #GMimeSigner
+ *
+ * Get the creation date of the signer's key.
+ *
+ * Returns: the creation date of the signer's key.
+ **/
+time_t
+g_mime_signer_get_created (GMimeSigner *signer)
+{
+	g_return_val_if_fail (signer != NULL, (time_t) -1);
+	
+	return signer->created;
+}
+
+
+/**
+ * g_mime_signer_set_expires:
+ * @signer: a #GMimeSigner
+ * @expires: expiration date
+ *
+ * Set the signer's key expiration date.
+ **/
+void
+g_mime_signer_set_expires (GMimeSigner *signer, time_t expires)
+{
+	g_return_if_fail (signer != NULL);
+	
+	signer->expires = expires;
+}
+
+
+/**
+ * g_mime_signer_get_expires:
+ * @signer: a #GMimeSigner
+ *
+ * Get the expiration date of the signer's key.
+ *
+ * Returns: the expiration date of the signer's key.
+ **/
+time_t
+g_mime_signer_get_expires (GMimeSigner *signer)
+{
+	g_return_val_if_fail (signer != NULL, (time_t) -1);
+	
+	return signer->expires;
+}
+
+
 /**
  * g_mime_signature_validity_new:
  *
  * Creates a new #GMimeSignatureValidity.
  *
- * Returns a new #GMimeSignatureValidity.
+ * Returns: a new #GMimeSignatureValidity.
  **/
 GMimeSignatureValidity *
 g_mime_signature_validity_new (void)
@@ -499,10 +793,10 @@ g_mime_signature_validity_free (GMimeSignatureValidity *validity)
  *
  * Gets the signature status (GOOD, BAD, UNKNOWN).
  *
- * Returns a #GMimeSignatureStatus value.
+ * Returns: a #GMimeSignatureStatus value.
  **/
 GMimeSignatureStatus
-g_mime_signature_validity_get_status (GMimeSignatureValidity *validity)
+g_mime_signature_validity_get_status (const GMimeSignatureValidity *validity)
 {
 	g_return_val_if_fail (validity != NULL, GMIME_SIGNATURE_STATUS_NONE);
 	
@@ -533,10 +827,10 @@ g_mime_signature_validity_set_status (GMimeSignatureValidity *validity, GMimeSig
  *
  * Gets any user-readable status details.
  *
- * Returns a user-readable string containing any status information.
+ * Returns: a user-readable string containing any status information.
  **/
 const char *
-g_mime_signature_validity_get_details (GMimeSignatureValidity *validity)
+g_mime_signature_validity_get_details (const GMimeSignatureValidity *validity)
 {
 	g_return_val_if_fail (validity != NULL, NULL);
 	
@@ -567,11 +861,11 @@ g_mime_signature_validity_set_details (GMimeSignatureValidity *validity, const c
  *
  * Gets the list of signers.
  *
- * Returns a #GMimeSigner list which contain further information such
+ * Returns: a #GMimeSigner list which contain further information such
  * as trust and cipher keys.
  **/
 const GMimeSigner *
-g_mime_signature_validity_get_signers (GMimeSignatureValidity *validity)
+g_mime_signature_validity_get_signers (const GMimeSignatureValidity *validity)
 {
 	g_return_val_if_fail (validity != NULL, NULL);
 	
@@ -604,164 +898,3 @@ g_mime_signature_validity_add_signer  (GMimeSignatureValidity *validity, GMimeSi
 		s->next = signer;
 	}
 }
-
-
-
-
-
-/**
- * g_mime_cipher_validity_new:
- *
- * Creates a new validity structure.
- *
- * WARNING: This interface has been deprecated. Use
- * g_mime_signature_validity_new() instead.
- *
- * Returns a new #GMimeCipherValidity.
- **/
-GMimeCipherValidity *
-g_mime_cipher_validity_new (void)
-{
-	return g_mime_signature_validity_new ();
-}
-
-
-/**
- * g_mime_cipher_validity_init:
- * @validity: validity structure
- *
- * Initializes the validity structure.
- *
- * WARNING: This interface has been deprecated.
- **/ 
-void
-g_mime_cipher_validity_init (GMimeCipherValidity *validity)
-{
-	g_assert (validity != NULL);
-	
-	validity->status = GMIME_SIGNATURE_STATUS_NONE;
-	validity->details = NULL;
-	validity->signers = NULL;
-}
-
-
-/**
- * g_mime_cipher_validity_get_valid:
- * @validity: validity structure
- *
- * Gets the validity of the validity structure @validity.
- *
- * WARNING: This interface has been deprecated. Use
- * g_mime_signature_validity_get_status() instead.
- *
- * Returns %TRUE if @validity is valid or %FALSE otherwise.
- **/
-gboolean
-g_mime_cipher_validity_get_valid (GMimeCipherValidity *validity)
-{
-	if (validity == NULL)
-		return FALSE;
-	
-	return validity->status == GMIME_SIGNATURE_STATUS_GOOD;
-}
-
-
-/**
- * g_mime_cipher_validity_set_valid:
- * @validity: validity structure
- * @valid: %TRUE if valid else %FALSE
- *
- * Sets the validness on the validity structure.
- *
- * WARNING: This interface has been deprecated. Use
- * g_mime_signature_validity_set_status() instead.
- **/
-void
-g_mime_cipher_validity_set_valid (GMimeCipherValidity *validity, gboolean valid)
-{
-	g_assert (validity != NULL);
-	
-	validity->status = valid ? GMIME_SIGNATURE_STATUS_GOOD : GMIME_SIGNATURE_STATUS_BAD;
-}
-
-
-/**
- * g_mime_cipher_validity_get_description:
- * @validity: validity structure
- *
- * Gets the description set on the validity structure @validity.
- *
- * WARNING: This interface has been deprecated. Use
- * g_mime_signature_validity_get_details() instead.
- *
- * Returns any description set on the validity structure.
- **/
-const char *
-g_mime_cipher_validity_get_description (GMimeCipherValidity *validity)
-{
-	return g_mime_signature_validity_get_details (validity);
-}
-
-
-/**
- * g_mime_cipher_validity_set_description:
- * @validity: validity structure
- * @description: validity description
- *
- * Sets the description on the validity structure.
- *
- * WARNING: This interface has been deprecated. Use
- * g_mime_signature_validity_set_details() instead.
- **/
-void
-g_mime_cipher_validity_set_description (GMimeCipherValidity *validity, const char *description)
-{
-	g_mime_signature_validity_set_details (validity, description);
-}
-
-
-/**
- * g_mime_cipher_validity_clear:
- * @validity: validity structure
- *
- * Clears the contents of the validity structure.
- *
- * WARNING: This interface has been deprecated.
- **/
-void
-g_mime_cipher_validity_clear (GMimeCipherValidity *validity)
-{
-	GMimeSigner *signer, *next;
-	
-	g_assert (validity != NULL);
-	
-	validity->status = GMIME_SIGNATURE_STATUS_NONE;
-	g_free (validity->details);
-	validity->details = NULL;
-	
-	signer = validity->signers;
-	while (signer != NULL) {
-		next = signer->next;
-		g_free (signer->fingerprint);
-		g_free (signer->keyid);
-		g_free (signer->name);
-		g_free (signer);
-		signer = next;
-	}
-}
-
-
-/**
- * g_mime_cipher_validity_free:
- * @validity: validity structure
- *
- * Frees the memory used by @validity back to the system.
- *
- * WARNING: This interface has been deprecated. Use
- * g_mime_signature_validity_free() instead.
- **/
-void
-g_mime_cipher_validity_free (GMimeCipherValidity *validity)
-{
-	g_mime_signature_validity_free (validity);
-}
