@@ -1,20 +1,21 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*  GMime
- *  Copyright (C) 2000-2007 Jeffrey Stedfast
+ *  Copyright (C) 2000-2008 Jeffrey Stedfast
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
+ *  This library is free software; you can redistribute it and/or
+ *  modify it under the terms of the GNU Lesser General Public License
+ *  as published by the Free Software Foundation; either version 2.1
+ *  of the License, or (at your option) any later version.
  *
- *  This program is distributed in the hope that it will be useful,
+ *  This library is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *  Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  You should have received a copy of the GNU Lesser General Public
+ *  License along with this library; if not, write to the Free
+ *  Software Foundation, 51 Franklin Street, Fifth Floor, Boston, MA
+ *  02110-1301, USA.
  */
 
 
@@ -41,22 +42,33 @@ G_BEGIN_DECLS
 typedef struct _GMimeMessage GMimeMessage;
 typedef struct _GMimeMessageClass GMimeMessageClass;
 
+
+/**
+ * GMimeMessage:
+ * @parent_object: parent #GMimeObject
+ * @mime_part: toplevel MIME part
+ * @recipients: hash table of recipients using recipient header name as the hash key
+ * @message_id: Message-Id string
+ * @reply_to: Reply-To string
+ * @subject: Subject string
+ * @from: From string
+ * @date: Date value
+ * @tz_offset: timezone offset
+ *
+ * A MIME Message object.
+ **/
 struct _GMimeMessage {
 	GMimeObject parent_object;
 	
-	char *from;
-	char *reply_to;
-	
+	GMimeObject *mime_part;
 	GHashTable *recipients;
-	
+	char *message_id;
+	char *reply_to;
 	char *subject;
+	char *from;
 	
 	time_t date;
-	int gmt_offset;     /* GMT offset */
-	
-	char *message_id;
-	
-	GMimeObject *mime_part;
+	int tz_offset;
 };
 
 struct _GMimeMessageClass {
@@ -101,15 +113,17 @@ void g_mime_message_set_reply_to (GMimeMessage *message, const char *reply_to);
 const char *g_mime_message_get_reply_to (GMimeMessage *message);
 
 void g_mime_message_add_recipient (GMimeMessage *message, char *type, const char *name, const char *address);
-void g_mime_message_add_recipients_from_string (GMimeMessage *message, char *type, const char *string);
+void g_mime_message_add_recipients_from_string (GMimeMessage *message, char *type, const char *str);
 const InternetAddressList *g_mime_message_get_recipients (GMimeMessage *message, const char *type);
+InternetAddressList *g_mime_message_get_all_recipients (GMimeMessage *message);
 
 void g_mime_message_set_subject (GMimeMessage *message, const char *subject);
 const char *g_mime_message_get_subject (GMimeMessage *message);
 
-void g_mime_message_set_date (GMimeMessage *message, time_t date, int gmt_offset);
-void g_mime_message_get_date (GMimeMessage *message, time_t *date, int *gmt_offset);
-char *g_mime_message_get_date_string (GMimeMessage *message);
+void g_mime_message_set_date (GMimeMessage *message, time_t date, int tz_offset);
+void g_mime_message_get_date (GMimeMessage *message, time_t *date, int *tz_offset);
+void g_mime_message_set_date_as_string (GMimeMessage *message, const char *str);
+char *g_mime_message_get_date_as_string (GMimeMessage *message);
 
 void g_mime_message_set_message_id (GMimeMessage *message, const char *message_id);
 const char *g_mime_message_get_message_id (GMimeMessage *message);
@@ -121,14 +135,6 @@ const char *g_mime_message_get_header (GMimeMessage *message, const char *header
 GMimeObject *g_mime_message_get_mime_part (GMimeMessage *message);
 void g_mime_message_set_mime_part (GMimeMessage *message, GMimeObject *mime_part);
 
-#ifndef GMIME_DISABLE_DEPRECATED
-ssize_t g_mime_message_write_to_stream (GMimeMessage *message, GMimeStream *stream);
-char *g_mime_message_to_string (GMimeMessage *message);
-#endif /* GMIME_DISABLE_DEPRECATED */
-
-char *g_mime_message_get_body (const GMimeMessage *message, gboolean want_plain, gboolean *is_html);
-char *g_mime_message_get_headers (GMimeMessage *message);
-
 void g_mime_message_foreach_part (GMimeMessage *message, GMimePartFunc callback, gpointer data);
 
 G_END_DECLS
