@@ -171,7 +171,7 @@ uuencode (const char *progname, int argc, char **argv)
 	
 	istream = g_mime_stream_fs_new (fd);
 	
-	fstream = g_mime_stream_filter_new_with_stream (ostream);
+	fstream = g_mime_stream_filter_new (ostream);
 	
 	filter = g_mime_filter_basic_new (encoding, TRUE);
 	g_mime_stream_filter_add ((GMimeStreamFilter *) fstream, filter);
